;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                            Variables                                    ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

globals
[
  ; parameters for the initialisation of individuals
  Bmax-mean      ;;maximum biomasses mean
  Bmax-sd        ;;maximum biomasses standard deviation
  Bo-mean        ;;Initial biomasses mean
  Bo-sd          ;;Initial biomasses standard deviation
  r-mean         ;;Growth rates mean
  r-sd           ;;Growth rates standard deviation
  
  ; parameters and global variables for the hexagonal packing:
  x-hex          ;;for the X positions of individuals
  y-hex          ;;for the Y positions of individuals
  i-hex          ;;how many individuals on the X axis
  j-hex          ;;how many individuals on the Y axis
  spacingx       ;;space between individuals on the X axis
  spacingy       ;;space between individuals on the Y axis
  y-offset       ;;space between rows of individuals on the Y axis
  
  size-factor    ;; depending on the grid size, take care of the display sizes of individuals
  
  ;;___________________________________
  ;; globals defined on the interface:
  ;;___________________________________
  ;; density                   ;; chooser,   define the initial number of individuals to install on the simulation area
  ;; regular-organisation      ;; switch,    if on, set the installation of individuals following an hexagonal packing, otherwise random
  ;; asymmetric-competition    ;; switch,    if on, use the asymmetric competition algorithm to attribute the Ae to each individual, otherwise use the symmetric competition one
  ;; grid                      ;; switch,    if on, display the grid (for interface only)
  ;;___________________________________
  ;;      Additional things:
  ;;___________________________________
  ;; remove-dead               ;; switch,    if on, the dead individuals are removed from the collection of individuals
  ;; grperc-crit               ;; number,    growth percent threshold deciding of the death of individuals, by default 0, but can be set to some values between 0 and r-mean
]

turtles-own
[
  Bmax   ;;maximum biomass
  B      ;;biomass
  r      ;;growth rate
  Ae    ;;effective area
  rad    ;; radius
  ;;the display radius is stored in size / 2
  ;;___________________________________
  ;;      Additional things:
  ;;___________________________________
  grperc      ;; realised growth percent compare to actual biomass
]

patches-own
[  
  nb-sharing    ;;Store the quality of the grid in a) number of individuals to share it (symmetric competition) or b) ID of the user individual (asymmetric competition)
]





;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                            setup                                        ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  clear-all
  ;random-seed 10020
  set-default-shape turtles "circle"
  set Bmax-mean 20000
  set Bmax-sd 2000
  set Bo-mean 1.0
  set Bo-sd 0.1
  set r-mean 1.0
  set r-sd 0.1
 
 
  ask patches [set nb-sharing 0]
  
  set size-factor ((world-width) / 100)

  if regular-organisation 
  [ 
     set j-hex  factor density
     set i-hex density / (2 * j-hex)
     set spacingx world-width / (2 * i-hex)
     set spacingy world-height / (2 * j-hex)
     set x-hex spacingx / 2
     set y-hex spacingy / 2 
     set y-offset spacingy / 2 
  ]
  
      
  crt density 
  [
    set B random-normal Bo-mean Bo-sd
    set Bmax random-normal Bmax-mean Bmax-sd
    set r random-normal r-mean r-sd
    set rad ( B ^ (2 / 6) ) * ( PI ^ ( -1 / 2 ) )  
    set Ae ( B ^ (2 / 3) )
    set size rad * size-factor * 2
    set grperc 1
    ifelse regular-organisation 
    [ hexagonal ]
    [ setxy random-xcor random-ycor ]
    set color scale-color green size (( size-factor * ( ( Bo-mean + 2 * Bo-sd ) ^ ( 2 / 3 ) ) ) * 0.1 )   (( size-factor * ( ( Bo-mean + 2 * Bo-sd ) ^ ( 2 / 3 ) ) ) * 2)
  ]
  
  if grid [print-grid]
  reset-ticks
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                  go stuffs                              ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go
  
  
  ifelse asymmetric-competition
  [ 
    ask patches [set nb-sharing 10000]
    ask turtles [attribute-grids]
    ask turtles [zoi-asym] 
  ]
  [
    ask patches [set nb-sharing 0]
    ask turtles [share-grids] 
    ask patches with [nb-sharing > 0] [set nb-sharing 1 / nb-sharing]
    ask turtles [zoi-sym] 
  ]
  ask turtles [grow]
  if count turtles <= 1 [stop]
  ;;display and plotting stuffs
  auto-plot-on
  
  set-current-plot "Histogram of sizes of individuals"
  histogram [B] of turtles
  
  set-current-plot "Coefficient of variation of mass through time"
  plotxy (ticks + 1)  (100 * standard-deviation [B] of turtles / mean [B] of turtles )
  
  set-current-plot "Mean mass through time"
  plotxy (ticks + 1) mean [B] of turtles
  

  ;;      Additional things:
  set-current-plot "self-thinning pattern"
  plotxy (ln count turtles) (ln mean [B] of turtles )

  set-current-plot "Realised growth"
  plotxy (ticks + 1) (mean [grperc] of turtles)

  
  ;; time step
  tick
end


to go-30
  repeat 30
  [
    go
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;              growth                               ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to grow    ;;turtle procedure
    let gr r * ( Ae - ( ( B ^ 2 ) / ( Bmax ^ ( 4 / 3 ) ) ) ) 
    set grperc ( gr ) / B
    ifelse grperc > grperc-crit
    [
        set B ( B + gr )
        set rad ( B ^ (2 / 6) ) * ( PI ^ ( -1 / 2 ) ) 
        set size rad * size-factor * 2
    ]
    [
        ;;show "One dying"
        if remove-dead [die]
    ]

end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; asymmetrical competition calculation of effective area  ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to zoi-asym    ;;turtle procedure
  let nbtot (count patches in-radius (size / 2))
  let nbsh  (count patches in-radius (size / 2) with [nb-sharing = [who] of myself])
  if nbsh > nbtot [show "problemmmmmm!!!!"]
  ifelse nbsh = 0
  [ set Ae 0 ]
  [ set Ae ( B ^ (2 / 3) ) * nbsh / nbtot ]
end

to attribute-grids    ;;turtle procedure
  ask patches in-radius (size / 2)
  [ 
    ifelse nb-sharing = 10000 
    [
      set nb-sharing [who] of myself
    ]
    [
      ifelse ([size] of turtle (nb-sharing)) > [size] of myself
      [
        ;;do nothing
      ]
      [
        set nb-sharing [who] of myself
      ]
    ]
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; symmetrical competition calculation of effective area  ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to zoi-sym    ;;turtle procedure
  let nbtot (count patches in-radius (size / 2))
  let nbsh  (sum ([nb-sharing] of patches in-radius (size / 2)))
  set Ae ( B ^ (2 / 3) ) * nbsh / nbtot
end

to share-grids    ;;turtle procedure
  ask patches in-radius (size / 2)
  [set nb-sharing nb-sharing + 1]
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; hexagonal packing installation ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to hexagonal    ;;turtle procedure
  ifelse y-hex > world-height
  [    show "too many point"  ]
  [
    setxy x-hex y-offset ;install at the prepared spot
    ;prepare the next one...
    set x-hex x-hex + spacingx
    ifelse y-offset = y-hex
    [  set y-offset y-offset + spacingy ]
    [  set y-offset y-hex ]
    
    if x-hex > world-width
    [    set x-hex spacingx / 2 
         set y-hex y-hex + 2 * spacingy 
         set y-offset y-hex
    ]
  ]
end

to-report factor [n]  ;; return the smallest integer divider of n larger than its square root (translated directly from Weiner's code)
  let root floor(sqrt(n))
    
  while [(n / root) < root] [
   set root root + 1
  ]
  report root
end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;       display stuffs            ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to print-grid
  ask patches with [remainder (pxcor + pycor ) 2 > 0 ]
  [
    set pcolor grey
  ] 
end
@#$#@#$#@
GRAPHICS-WINDOW
269
36
779
567
-1
-1
1.0
1
10
1
1
1
0
1
1
1
0
499
0
499
1
1
1
ticks
30.0

BUTTON
74
10
129
43
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
6
10
69
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
133
10
188
43
NIL
go-30
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
7
53
194
86
regular-organisation
regular-organisation
1
1
-1000

CHOOSER
8
133
146
178
density
density
100 506 992 4970
0

PLOT
796
12
1239
339
Histogram of sizes of individuals
classes
Frequency
0.0
3000.0
0.0
100.0
true
false
"" ""
PENS
"default" 100.0 1 -8630108 true "" ""

SWITCH
157
138
260
171
grid
grid
1
1
-1000

SWITCH
7
92
193
125
asymmetric-competition
asymmetric-competition
1
1
-1000

PLOT
797
343
1240
549
Coefficient of variation of mass through time
time
CV %
0.0
30.0
0.0
100.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

BUTTON
193
10
248
43
go-once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
11
183
261
539
Mean mass through time
time
Mass
0.0
30.0
0.0
1250.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
571
683
839
861
self-thinning pattern
log density
log biomass
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 2 -16777216 true "" ""

MONITOR
1093
30
1232
75
Maximum individual biomass
max [B] of turtles
2
1
11

MONITOR
919
30
1090
75
Minimum individual biomass (alive)
min [B] of turtles
2
1
11

TEXTBOX
309
14
769
40
AZOI model, reimplementation of the ZOI model of Weiner et al. (2001)
14
13.0
1

SWITCH
388
639
524
672
remove-dead
remove-dead
1
1
-1000

INPUTBOX
290
611
382
671
grperc-crit
0
1
0
Number

PLOT
291
684
559
861
Realised growth
time
Mean growth
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

MONITOR
537
629
616
674
Nb turtles
count turtles
0
1
11

MONITOR
626
628
728
673
Minimum growth
min [grperc] of turtles
4
1
11

MONITOR
736
629
838
674
Maximum growth
max [grperc] of turtles
4
1
11

TEXTBOX
467
582
617
601
Supplementary stuffs
15
14.0
0

TEXTBOX
135
600
285
684
grperc-crit = growth percent threshold deciding of the death of individuals, by default 0, but can be set to some values between 0 and r-mean (1, set in the code)
11
0.0
1

@#$#@#$#@
#AZOI model description

The AZOI model (Another Zone Of Influence) was re-implemented according to the model developed and used by Weiner et al. (2001). The model description follows the ODD protocol for describing individual- and agent-based models (Grimm et al. 2006; Grimm and Railsback 2005) and consists of seven elements. The first three elements provide an overview, the fourth element explains general concepts underlying the model’s design, and the remaining three elements provide details.

#Purpose

The purpose of the AZOI model is to show the combined effect of competition regime (from total asymmetry to symmetrical share of resources), density and spatial distribution on the sizes and size distributions of plants.

#State variables and scales

•	The agents of the AZOI model are individual plants represented by their zone of influence (ZOI) where they collect and share areas considered as their primary resource. In this Netlogo implementation, each plant is a turtle and the area is discretely divided in patches.
•	As state variables, each plant has its own biomass (B), maximum biomass (Bmax), optimal growth rate (r) and position on the simulated area. Additionally, at each time step the radius of interaction (rad) and the effective area (i.e. the ZOI area minus the part lost to neighbors) that each plant can use (Ae) are calculated and stored in the parameters of the individuals. The quality of patches can be either qualified in term of ownership to specific plants in the asymmetric competition version, or receive a value of inverse number of competing plant at this patch in the symmetric competition version. In Netlogo:

turtles-own[Bmax B r Ae rad …]

•	The simulation area is 100 by 100 cm, divided in 500 by 500 patches (each patch is thus 0.2cm by 0.2cm, i.e. 0.04cm2). The area is considered as a torus world (i.e. periodic boundaries). The time step is considered as a growing period and the simulations are usually run for 30 steps.

#Process overview and scheduling

As first process of a time step, the patches are assigned a quality depending on the competition submodel (symmetric or asymmetric). The effective area of each plant is then calculated depending on the quality of the patches within its ZOI radius. And finally each plant is grown by an individual-specific rate calculated out of its available effective area and its growth parameters.

#Design concepts

##Emergence. 
The size distribution of the plants is the major emergent property of the systems modelled by the AZOI model and is dependent on the type of competition regime, density and spatial organization of the individuals. 
##Interaction. 
Individual plants interact through overlap of their zones of influences. This interaction determine how well the plant grow on each time step
##Stochasticity. 
Sizes, growth parameter values and positions (when not regularly installed) of individuals are decided randomly at initialisation.
##Observation. 
The biomass of each individual is the most important output and on which are based most of the other observations. A plot of mean biomass through time indicates the general fate of the population depending on the simulation settings. A histogram of number of individuals per biomass classes gives information about the spread and shape of the size distribution. A plot of coefficient of variation of biomass (standard deviation divided by mean) is showing how much variation of biomass occurs and at different time with different simulation settings.


#Initialization

The simulations are prepared by first clearing all left-over from previous simulations. The parameters used for hexagonal installation are then eventually calculated. As many plants (turtles) as given by the density input value (see Table 1 of pdf) are then installed randomly or following a hexagonal packing configuration. Each plant receives an initial biomass, maximal biomass and optimal growth rate determined randomly following a normal distribution defined by a mean and standard deviation for each parameter (see Table 1 of pdf). 


#Input

No inputs are given to the simulations after their initialization.

#Submodels

See attached pdf (equations are not nice here!)


# REFERENCES:

Grimm, V., U. Berger, F. Bastiansen, S. Eliassen, V. Ginot, J. Giske, J. Goss-Custard, T. Grand, S. Heinz, G. Huse, A. Huth, J. U. Jepsen, C. Jorgensen, W. M. Mooij, B. Mueller, G. Pe'er, C. Piou, S. F. Railsback, A. M. Robbins, M. M. Robbins, E. Rossmanith, N. Rüger, E. Strand, S. Souissi, R. A. Stillman, R. Vabo, U. Visser, and D. L. DeAngelis. 2006. A standard protocol for describing individual-based and agent-based models. Ecological Modelling 198:115-126.

Grimm, V., and S. F. Railsback. 2005. Individual-based modeling and ecology. Princetown University Press, Princeton, N.J.

Weiner, J., P. Stoll, H. Muller-Landau, and A. Jasentuliyana. 2001. The effects of density, spatial pattern, and competitive symmetry on size variation in simulated plant populations. The American Naturalist, 158:438-450

Stoll, P., J. Weiner, H. Muller-Landau, E. Müller and T. Hara. 2002. Size symmetry of competition alters biomass–density relationships. Proceedings of the Royal Society, London Series B, 269:2191-2195


@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="all possibilities" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="30"/>
    <metric>mean [B] of turtles</metric>
    <metric>[B] of turtles</metric>
    <enumeratedValueSet variable="regular-organisation">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="asymmetric-competition">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="density">
      <value value="100"/>
      <value value="506"/>
      <value value="992"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-sf" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <exitCondition>count turtles &lt; 3</exitCondition>
    <metric>count turtles</metric>
    <metric>sum [B] of turtles</metric>
    <enumeratedValueSet variable="asymmetric-competition">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grid">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grperc-crit">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="density">
      <value value="4970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="regular-organisation">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="remove-dead">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
